==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/ts/File_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Plik
Os&amp;tatnio otwierane pliki</translatorcomment>
        <translation type="unfinished">&amp;Plik</translation>
    </message>
    <message>
        <location line="+63"/>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:
Format:</translatorcomment>
        <translation type="unfinished">Format:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Overwrite File?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nadpisz plik?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">&apos;&amp;#39; Plik już istnieje. Czy chcesz go zastąpić?</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/ts/File_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Narzędzia pliku</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Wyświetla narzędzia pliku</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Plik
Os&amp;tatnio otwierane pliki</translatorcomment>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location line="+91"/>
        <location line="+69"/>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:
Format:</translatorcomment>
        <translation>Format:</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Overwrite File?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastąpić plik?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Plik „%1” już istnieje. Zastąpić go?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All Files</source>
        <translation>Wszystkie pliki</translation>
    </message>
</context>
</TS>
